#!/bin/bash

DATABASE="__DATABASE__"
USER="zabbix"
PASSWORD="Default1.ZBX-PassW0rd"

DATA="$1"
if [[ -z "$DATA" ]]; then
  echo "Usage: ${0##*/} <data> [mysql createdb options]" >&2
  echo "Data is either \`NEW' or a SQL file name or \`-' for STDIN." >&2
  exit 1
fi
shift

# Show a status line if possible
if dd status=progress count=0 2> /dev/null; then
  PROGRESS="dd status=progress"
else
  PROGRESS="cat"
fi

# Check for `sed' in case we need it as a filter below
if ! command -v "sed" > /dev/null; then
  echo "Error: unable to run \`sed', exiting!" >&2
  exit 1
fi

cat << EOF | mysql "$@"
DROP DATABASE IF EXISTS \`${DATABASE}\`;
DROP USER IF EXISTS '${USER}'@'localhost';
CREATE DATABASE \`${DATABASE}\` CHARACTER SET 'utf8mb4' COLLATE 'utf8mb4_bin';
CREATE USER '${USER}'@'localhost' IDENTIFIED BY '${PASSWORD}';
GRANT ALL PRIVILEGES ON ${DATABASE}.* TO '${USER}'@'localhost';
SET GLOBAL log_bin_trust_function_creators = 1;
EOF

{
  case "$DATA" in

    NEW)
      cd "$(dirname "$0")"
      for F in "schema" "images" "data"; do
        DATA="${F}.sql.gz"
        if [[ -r "$DATA" ]]; then
          gzip -cd "$DATA"
        else
          echo "Error: unable to read file \`${DATA}', exiting!" >&2
          exit 1
        fi
        # For zabbix_proxy we need only the schema
        if [[ "$DATABASE" == "zabbix_proxy" ]]; then
          break
        fi
      done
      ;;

    *)
      if [[ "$DATA" == "-" ]]; then
        READER="cat"
      elif [[ -r "$DATA" ]]; then
        # Try to be smart about input of compressed files
        if command -v "lesspipe.sh" > /dev/null; then
          READER="lesspipe.sh"
        else
          READER="cat"
        fi
      else
        echo "Error: unable to read file \`${DATA}', exiting!" >&2
        exit 1
      fi
      # Restore from backup
      $READER "$DATA"
      # Upgrade to use double precision values
      cd "$(dirname "$0")"
      DATA="option-patches/double.sql.gz"
      if [[ -r "$DATA" ]]; then
        gzip -cd "$DATA"
      else
        echo "Error: unable to read file \`${DATA}', exiting!" >&2
        exit 1
      fi
      ;;

  esac
} | $PROGRESS | mysql "$@" --default-character-set=utf8mb4 \
  --user="$USER" --password="$PASSWORD" --database="$DATABASE"

if [[ "$DATA" != "NEW" ]]; then
  echo "Backup of database \`${DATABASE}' has been imported."
  echo "Start zabbix server/proxy now to upgrade the database, then stop it"
  echo "again and perform any required upgrade steps as documented here:"
  echo
  echo "https://www.zabbix.com/documentation/<version>/en/manual/appendix/install/db_charset_coll"
  echo
  echo "Once the upgrade is done, reset \`log_bin_trust_function_creators' again:"
  echo
  echo "mysql -e \"SET GLOBAL log_bin_trust_function_creators = 0;\""
  exit 0
fi

mysql "$@" -e "SET GLOBAL log_bin_trust_function_creators = 0;"
