%global name zabbix
%global version 6.0.39
%global rpmrelease 2

# beta is either 0 or something like rc1
%global beta 0

# Extract main version from Zabbix version numbers
%global mainversion %(echo %{version} | cut -d "." -f -2)

# additional versions
%global _javaversion 8
%global _logbackversion 1.3.15
%global _slf4jversion 2.0.17

# build options
%global _srvuser zbxsrv
%global _webappsdir %{_datadir}/%{name}/ui

# systemd options
%global _has_systemd %(rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

# only >= EL8 support crypto-policies
%{!?_has_crypto_policies: %global _has_crypto_policies 1}

# only >= EL6 support to build servers
%{!?_build_servers: %global _build_servers 1}

%if %{_build_servers}
# do we have mysql or mariadb?
%global _mysqlname %(rpm -q --quiet mariadb-connector-c-devel && echo mariadb-connector-c || echo mysql)
# do we build with libssh and openssl? distributions with libssh also have openssl >= 1.0.1
%global _has_libssh %(rpm -q --queryformat '%{VERSION}\\n' openssl | head -n 1 | cut -d "." -f 1)
%if %{_has_libssh}
%global _sshname %(rpm -q --quiet libssh2-devel && echo ssh2 || echo ssh)
%endif
# do we have the required php major.minor version >= 7.2
%global _with_webui %([ $(rpm -q --queryformat '%{VERSION}' php | cut -d "." -f 1,2 | %{__sed} -e "s/\\.//g") -ge 72 ] && echo 1 || echo 0 )
%endif

Summary: Enterprise-class open source monitoring solution
Name: %{name}
Version: %{version}
%if "%{beta}" == "0"
Release: %{rpmrelease}%{?dist}
%else
Release: 0.0.%{beta}.%{rpmrelease}%{?dist}
%endif
License: GPL-2.0-or-later AND LGPL-2.0-or-later AND MIT AND X11 AND JSON
Group: System Environment/Daemons
URL: https://www.zabbix.com/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
%if "%{beta}" == "0"
Source0: https://cdn.zabbix.com/zabbix/sources/stable/%{mainversion}/%{name}-%{version}.tar.gz
%else
Source0: https://cdn.zabbix.com/zabbix/sources/release_candidates/%{mainversion}/%{name}-%{version}%{beta}.tar.gz
%endif
Source1: %{name}-agent.%{_servicefile_postfix}
Source2: %{name}-server.%{_servicefile_postfix}
Source3: %{name}-proxy.%{_servicefile_postfix}
Source4: %{name}-java.%{_servicefile_postfix}
Source5: zabbix-6.0.23-dbsetup.sh
Source6: zabbix-2.0-logrotate.in
Source7: zabbix-5.0.0-apache24.conf
Source8: zabbix-5.2.5-php-fpm72.conf
Source9: uname_wrapper
Source10: %{name}-java.sysconfig
Source11: %{name}_java.sh
Source12: zabbix-README.RPM
Source13: zabbix-6.0.23-db_primary_keys.sh
Source14: https://git.zabbix.com/projects/WEB/repos/documentation/raw/assets/en/manual/appendix/install/utf8mb4_convert.sql
%if %{_has_systemd}
Source15: %{name}-tmpfiles.conf
%endif
Source100: https://repo1.maven.org/maven2/ch/qos/logback/logback-classic/%{_logbackversion}/logback-classic-%{_logbackversion}.jar
Source101: https://repo1.maven.org/maven2/ch/qos/logback/logback-core/%{_logbackversion}/logback-core-%{_logbackversion}.jar
Source102: https://repo1.maven.org/maven2/org/slf4j/slf4j-api/%{_slf4jversion}/slf4j-api-%{_slf4jversion}.jar
Patch0: zabbix-6.0.32rc1-config.patch
Patch1: zabbix-6.0.13-agent_config_item.patch
Patch2: zabbix-1.8.6-pidfile.patch
Patch3: zabbix-2.0.4-java_log.patch
Patch4: zabbix-6.0.37-execute_path.patch
Patch5: zabbix-6.0.13-ui_config.patch
Patch6: zabbix-3.0.1-log_size.patch
Patch7: zabbix-3.2.5-fping_4.patch
%if %{_has_crypto_policies}
Patch8: https://src.fedoraproject.org/rpms/zabbix/raw/rawhide/f/zabbix-crypto-policy.patch
%endif
# patches => 100 should/will be fixed in SCM
BuildRequires: openssl-devel, openldap-devel, pcre-devel, sed
BuildRequires: %{_includedir}/linux/version.h
%if %{_build_servers}
BuildRequires: libcurl-devel >= 7.19.7, %{_mysqlname}-devel
BuildRequires: net-snmp-devel >= 5.3.0, unixODBC-devel, zlib-devel
BuildRequires: libxml2-devel, OpenIPMI-devel, libevent-devel >= 1.4
BuildRequires: java-openjdk >= %{_javaversion}, php
%if %{_has_libssh}
BuildRequires: openssl-devel >= 1.0.1, lib%{_sshname}-devel
%endif
%endif
Requires: logrotate
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%endif
Requires(pre): %{_sbindir}/useradd, %{_sbindir}/usermod
Requires(post): grep, sed
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
Zabbix is software that monitors numerous parameters of a network and
the servers on that network. Zabbix is a useful tool for monitoring
the health and integrity of servers. Zabbix uses a flexible
notification mechanism that allows users to configure email based
alerts for virtually any event. All monitored parameters are stored in a
MySQL database. Zabbix offers excellent reporting and data visualisation
features based on the stored data. Zabbix supports both polling and
trapping. All Zabbix reports and statistics, as well as configuration
parameters, are accessed through a web-based front end.

%package devel
Summary: Header files for development of modules for Zabbix
Group: Development/Libraries

%description devel
This package contains the header files needed to develop loadable
modules for extending Zabbix agent and server without sacrificing
performance.

%package agent
Summary: Zabbix Agent Daemon
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
%if %{_has_systemd}
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif

%description agent
This package provides the agent daemon for Zabbix.

%if %{_build_servers}
%package server
Summary: Zabbix Server Daemon
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}, net-snmp >= 5.3.0, fping >= 4
Requires: iputils, traceroute
%if %{_has_systemd}
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
Conflicts: %{name}-proxy

%description server
This package provides the server daemon for Zabbix.

%package proxy
Summary: Zabbix Proxy Daemon
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}, net-snmp >= 5.3.0, fping >= 4
%if %{_has_systemd}
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
Conflicts: %{name}-server

%description proxy
This package provides the proxy daemon for Zabbix.

%package java
Summary: Zabbix Java Gateway Daemon
Group: System Environment/Daemons
# only >= EL6 support mixed build archs
%{!?_sub_arch: %global _sub_arch noarch}
BuildArch: %{_sub_arch}
Requires: %{name} = %{version}-%{release}
%if %{_has_systemd}
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif

%description java
This package provides the java gateway daemon for Zabbix.

%if %{_with_webui}
%package webui
Summary: Zabbix Web Frontend
Group: Applications/Internet
# only >= EL6 support mixed build archs
%{!?_sub_arch: %global _sub_arch noarch}
BuildArch: %{_sub_arch}
Requires: php-fpm >= 7.2.5, php-bcmath, php-gd, php-gettext
Requires: php-json, php-ldap, php-mbstring, php-mysqli, php-xml
Requires: php(httpd), httpd-filesystem >= 2.4.0, dejavu-sans-fonts

%description webui
This package contains the web based (PHP) user interface for Zabbix.
%endif
%endif

%prep
%if "%{beta}" == "0"
%setup -q
%else
%setup -q -n %{name}-%{version}%{beta}
%endif

# preserve timestamps of some build configuration files
for F in configure configure.ac; do
  %{__cp} -a $F ${F}.$$
done

# apply SCM patches first, other patches my depend on them

# do all other patches
%patch0 -p1 -b .config
%patch1 -p1 -b .agent_config_item
%patch2 -p1 -b .pidfile
%patch3 -p1 -b .java_log
%patch4 -p1 -b .execute_path
%patch5 -p1 -b .ui_config
%patch6 -p1 -b .log_size
%patch7 -p1 -b .fping_4
%if %{_has_crypto_policies}
%patch8 -p1 -b .crypto-policy
%endif

# restore preserved timestamps
for F in configure configure.ac; do
  touch -r ${F}.$$ $F
done

# install build wrappers
%{__install} -d build_wrappers
%{__install} -m 0755 -p %{SOURCE9} build_wrappers/uname

# add LIBDIR path to config files
for F in conf/zabbix_*.conf; do
  %{__sed} -e "s@__LIBDIR__@%{_libdir}@g" $F > ${F}.$$
  %{__mv} -vf ${F}.$$ $F
done

# add RUNDIR path to config and source files
for F in conf/zabbix_*.conf src/zabbix_*/*.{c,sh}; do
  %{__sed} -e "s@__RUNDIR__@%{_pidbasedir}@g" $F > ${F}.$$
  %{__mv} -vf ${F}.$$ $F
done

# generate logrotate config files
for P in agentd server proxy java; do
  echo "generate %{name}_${P}.logrotate"
  case $P in
    agentd)
      D=%{name}
      ;;
    *)
      D=%{name}-servers
      ;;
  esac
  %{__sed} \
    -e "s@__LOGDIR__@${D}@g" \
    -e "s@__FILE__@%{name}_${P}@g" \
    %{SOURCE6} > %{name}_${P}.logrotate
  touch -r %{SOURCE6} %{name}_${P}.logrotate
done

# update logback
%{__rm} -vf src/%{name}_java/lib/logback-*.jar
%{__rm} -vf src/%{name}_java/lib/slf4j-api-*.jar
%{__install} -m 0644 -p %{SOURCE100} src/%{name}_java/lib/
%{__install} -m 0644 -p %{SOURCE101} src/%{name}_java/lib/
%{__install} -m 0644 -p %{SOURCE102} src/%{name}_java/lib/

%build
# use build wrappers
PATH=./build_wrappers:${PATH}
%configure \
  --datadir=%{_localstatedir}/lib \
%if %{_build_servers}
  --enable-server \
  --enable-proxy \
  --enable-java \
  --with-mysql \
  --with-net-snmp \
  --with-libcurl \
  --with-unixodbc \
  --with-openipmi \
  --with-libevent \
  --with-libxml2 \
%if %{_has_libssh}
  --with-%{_sshname} \
  --with-openssl \
%endif
%endif
  --enable-agent \
  --with-ldap \
  --enable-ipv6 \
%{nil}

# build jar files list
cd src/%{name}_java
  for F in lib/*.jar; do
    if [ -z "$JARS" ]; then
      JARS=$F
    else
      JARS=${JARS}:${F}
    fi
  done
cd -

%{__make} JAVAC="javac -source %{_javaversion} -target %{_javaversion}" LIB="$JARS"

# build db creation files
%{__rm} -vf database/mysql/*.sql.*
%{__rm} -vf database/mysql/option-patches/*.sql.*
%{__gzip} database/mysql/*.sql
%{__gzip} database/mysql/option-patches/*.sql
%{__sed} -e "s@__DATABASE__@%{name}@g" %{SOURCE5} > database/mysql/dbsetup.sh
%{__sed} -e "s@__DATABASE__@%{name}_proxy@g" %{SOURCE5} > database/mysql/dbsetup_proxy.sh
%{__sed} -e "s@__DATABASE__@%{name}@g" %{SOURCE13} > database/mysql/db_primary_keys.sh
%{__sed} -e "s@__DATABASE__@%{name}_proxy@g" %{SOURCE13} > database/mysql/db_primary_keys_proxy.sh

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

# create package specific dirs
%{__install} -d %{buildroot}%{_sysconfdir}/logrotate.d
%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig
%if %{_has_systemd}
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%else
%{__install} -d %{buildroot}%{_initrddir}
%endif
%{__install} -d %{buildroot}%{_datadir}/%{name}
%{__install} -d %{buildroot}%{_localstatedir}/lib/{%{name},%{_srvuser}/tmp,%{_srvuser}/socket}
%{__install} -d %{buildroot}%{_localstatedir}/lib/%{_srvuser}/ssl/{certs,keys}
%{__install} -d %{buildroot}%{_libdir}/%{name}/modules
%{__install} -d %{buildroot}%{_includedir}/%{name}
%{__install} -d %{buildroot}%{_pidbasedir}/%{name}
%{__install} -d %{buildroot}%{_var}/log/%{name}
%{__install} -d %{buildroot}%{_var}/log/%{name}-servers

%{__make} install DESTDIR=%{buildroot} INSTALL="install -p" ZJG_DEST="%{buildroot}%{_datadir}/%{name}/java"

# install header files
%{__install} -m 0644 -p include/*.h %{buildroot}%{_includedir}/%{name}/

# install logrotate and systemd files and scripts
%if %{_has_systemd}
%{__install} -m 0644 -p %{SOURCE15} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_unitdir}/%{name}-agent.service
%else
%{__install} -m 0755 -p %{SOURCE1} %{buildroot}%{_initrddir}/%{name}-agent
%endif
%{__install} -m 0644 -p %{name}_agentd.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}_agentd
%if %{_build_servers}
%{__install} -m 0644 -p %{name}_server.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}_server
%{__install} -m 0644 -p %{name}_proxy.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}_proxy
%{__install} -m 0644 -p %{name}_java.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}_java
%{__install} -m 0644 -p %{buildroot}%{_datadir}/%{name}/java/settings.sh %{buildroot}%{_sysconfdir}/%{name}_java.conf
%{__install} -m 0644 -p %{SOURCE10} %{buildroot}%{_sysconfdir}/sysconfig/%{name}-java
%{__install} -m 0755 -p %{SOURCE11} %{buildroot}%{_datadir}/%{name}/java/bin/
%if %{_has_systemd}
%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_unitdir}/%{name}-server.service
%{__install} -m 0644 -p %{SOURCE3} %{buildroot}%{_unitdir}/%{name}-proxy.service
%{__install} -m 0644 -p %{SOURCE4} %{buildroot}%{_unitdir}/%{name}-java.service
%else
%{__install} -m 0755 -p %{SOURCE2} %{buildroot}%{_initrddir}/%{name}-server
%{__install} -m 0755 -p %{SOURCE3} %{buildroot}%{_initrddir}/%{name}-proxy
%{__install} -m 0755 -p %{SOURCE4} %{buildroot}%{_initrddir}/%{name}-java
%endif

# install db creation files
%{__mv} -vf database/mysql %{buildroot}%{_datadir}/%{name}/
%{__install} -m 0644 -p %{SOURCE14} %{buildroot}%{_datadir}/%{name}/mysql/

# install php user interface
%if %{_with_webui}
%{__install} -d %{buildroot}%{_sysconfdir}/httpd/conf.d
%{__install} -d %{buildroot}%{_sysconfdir}/php-fpm.d
%{__install} -m 0644 -p %{SOURCE7} %{buildroot}%{_sysconfdir}/httpd/conf.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE8} %{buildroot}%{_sysconfdir}/php-fpm.d/%{name}.conf
%{__mv} -vf ui %{buildroot}%{_webappsdir}
%{__mv} -vf %{buildroot}%{_webappsdir}/conf/zabbix.conf.php.example %{buildroot}%{_sysconfdir}/%{name}_webui.conf
%{__ln_s} -f ../../../../..%{_sysconfdir}/%{name}_webui.conf %{buildroot}%{_webappsdir}/conf/zabbix.conf.php
%{__mv} -vf %{buildroot}%{_webappsdir}/conf/maintenance.inc.php %{buildroot}%{_sysconfdir}/%{name}_webui_maintenance.conf
%{__ln_s} -f ../../../../..%{_sysconfdir}/%{name}_webui_maintenance.conf %{buildroot}%{_webappsdir}/conf/maintenance.inc.php

# remove files we don't need
find %{buildroot}%{_webappsdir}/ -name "*.php.*" -exec %{__rm} -vf {} \;
find %{buildroot}%{_webappsdir}/ -name ".htaccess" -exec %{__rm} -vf {} \;
find %{buildroot}%{_webappsdir}/locale/ -name "*.po" -exec %{__rm} -vf {} \;
%{__rm} -vf %{buildroot}%{_webappsdir}/locale/*.sh
%{__rm} -vf %{buildroot}%{_webappsdir}/locale/README
%endif
find %{buildroot}%{_datadir}/%{name}/ -name "Makefile*" -exec %{__rm} -vf {} \;
find %{buildroot}%{_datadir}/%{name}/java/ -name "*.xml.*" -exec %{__rm} -vf {} \;
%{__rm} -vf %{buildroot}%{_datadir}/%{name}/java/*.sh
%endif
%{__rm} -vf %{buildroot}%{_sysconfdir}/%{name}_agent.conf
%{__rm} -vfr %{buildroot}%{_sysconfdir}/%{name}_agent.d
%{__rm} -vf %{buildroot}%{_sbindir}/%{name}_agent

# install rpm specific files
%{__install} -m 0644 -p %{SOURCE12} README.RPM

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%pre
if getent passwd %{name} > /dev/null; then
  %{_sbindir}/usermod -d %{_localstatedir}/lib/%{name} %{name} 2> /dev/null || :
else
  %{_sbindir}/useradd -M -o -r -d %{_localstatedir}/lib/%{name} -u 95 -c "Zabbix User" -s /sbin/nologin %{name} 2> /dev/null || :
fi

%post
# cleanup old service entries if necessary
if %{__grep} -qe "^zabbix_" %{_sysconfdir}/services; then
  %{__sed} \
    -e 's@zabbix_agent\t10050/tcp\t\t\t# Zabbix Monitoring Agent@zabbix-agent    10050/tcp               # Zabbix Agent@g' \
    -e 's@zabbix_agent\t10050/udp\t\t\t# Zabbix Monitoring Agent@zabbix-agent    10050/udp               # Zabbix Agent@g' \
    -e 's@zabbix_trap\t10051/tcp\t\t\t# Zabbix Monitoring Trapper@zabbix-trapper  10051/tcp               # Zabbix Trapper@g' \
    -e 's@zabbix_trap\t10051/udp\t\t\t# Zabbix Monitoring Trapper@zabbix-trapper  10051/udp               # Zabbix Trapper@g' \
    < %{_sysconfdir}/services | %{__grep} -ve "^zabbix_" > %{_sysconfdir}/services.$$
  %{__mv} -f %{_sysconfdir}/services.$$ %{_sysconfdir}/services
fi
# add service entries if necessary
if ! %{__grep} -qe "^zabbix-agent" %{_sysconfdir}/services; then
  echo -e 'zabbix-agent    10050/tcp               # Zabbix Agent' >> %{_sysconfdir}/services
  echo -e 'zabbix-agent    10050/udp               # Zabbix Agent' >> %{_sysconfdir}/services
fi
if ! %{__grep} -qe "^zabbix-trapper" %{_sysconfdir}/services; then
  echo -e 'zabbix-trapper  10051/tcp               # Zabbix Trapper' >> %{_sysconfdir}/services
  echo -e 'zabbix-trapper  10051/udp               # Zabbix Trapper' >> %{_sysconfdir}/services
fi
if ! %{__grep} -qe "^zabbix-java" %{_sysconfdir}/services; then
  echo -e 'zabbix-java     10052/tcp               # Zabbix Java Gateway' >> %{_sysconfdir}/services
  echo -e 'zabbix-java     10052/udp               # Zabbix Java Gateway' >> %{_sysconfdir}/services
fi

%post agent
%if %{_has_systemd}
%systemd_post %{name}-agent.service
%else
/sbin/chkconfig --add %{name}-agent
%endif

%preun agent
%if %{_has_systemd}
%systemd_preun %{name}-agent.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name}-agent stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}-agent
fi
%endif

%postun agent
%if %{_has_systemd}
%systemd_postun_with_restart %{name}-agent.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name}-agent condrestart > /dev/null 2>&1 || :
fi
%endif

%if %{_build_servers}
%pre server
getent passwd %{_srvuser} > /dev/null || \
  %{_sbindir}/useradd -r -G %{name} -d %{_localstatedir}/lib/%{_srvuser} -c "Zabbix Server User" -s /sbin/nologin %{_srvuser} 2> /dev/null || :

%post server
%if %{_has_systemd}
%systemd_post %{name}-server.service
%else
/sbin/chkconfig --add %{name}-server
%endif

%preun server
%if %{_has_systemd}
%systemd_preun %{name}-server.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name}-server stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}-server
fi
%endif

%postun server
%if %{_has_systemd}
%systemd_postun_with_restart %{name}-server.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name}-server condrestart > /dev/null 2>&1 || :
fi
%endif

%pre proxy
getent passwd %{_srvuser} > /dev/null || \
  %{_sbindir}/useradd -r -G %{name} -d %{_localstatedir}/lib/%{_srvuser} -c "Zabbix Server User" -s /sbin/nologin %{_srvuser} 2> /dev/null || :

%post proxy
%if %{_has_systemd}
%systemd_post %{name}-proxy.service
%else
/sbin/chkconfig --add %{name}-proxy
%endif

%preun proxy
%if %{_has_systemd}
%systemd_preun %{name}-proxy.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name}-proxy stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}-proxy
fi
%endif

%postun proxy
%if %{_has_systemd}
%systemd_postun_with_restart %{name}-proxy.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name}-proxy condrestart > /dev/null 2>&1 || :
fi
%endif

%pre java
getent passwd %{_srvuser} > /dev/null || \
  %{_sbindir}/useradd -r -G %{name} -d %{_localstatedir}/lib/%{_srvuser} -c "Zabbix Server User" -s /sbin/nologin %{_srvuser} 2> /dev/null || :

%post java
%if %{_has_systemd}
%systemd_post %{name}-java.service
%else
/sbin/chkconfig --add %{name}-java
%endif

%preun java
%if %{_has_systemd}
%systemd_preun %{name}-java.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name}-java stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}-java
fi
%endif

%postun java
%if %{_has_systemd}
%systemd_postun_with_restart %{name}-java.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name}-java condrestart > /dev/null 2>&1 || :
fi
%endif
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING NEWS README README.RPM
%attr(0775,root,%{name}) %dir %{_pidbasedir}/%{name}
%attr(0755,root,root) %{_bindir}/%{name}_get
%attr(0755,root,root) %{_bindir}/%{name}_sender
%if %{_build_servers}
%attr(0755,root,root) %{_bindir}/%{name}_js
%endif
%attr(0755,%{name},%{name}) %dir %{_localstatedir}/lib/%{name}
%{_mandir}/man1/%{name}_get.1*
%{_mandir}/man1/%{name}_sender.1*
%if %{_has_systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%endif

%files devel
%defattr(-,root,root,-)
%{_includedir}/%{name}

%files agent
%defattr(-,root,root,-)
%attr(0640,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}_agentd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}_agentd
%attr(0750,%{name},%{name}) %dir %{_var}/log/%{name}
%attr(0750,root,%{name}) %dir %{_sysconfdir}/%{name}_agentd.conf.d
%if %{_has_systemd}
%{_unitdir}/%{name}-agent.service
%else
%attr(0755,root,root) %{_initrddir}/%{name}-agent
%endif
%attr(0755,root,root) %{_sbindir}/%{name}_agentd
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/modules
%{_mandir}/man8/%{name}_agentd.8*

%if %{_build_servers}
%files server
%defattr(-,root,root,-)
%doc misc/snmptrap/zabbix_trap_receiver.pl
%attr(0640,root,%{_srvuser}) %config(noreplace) %{_sysconfdir}/%{name}_server.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}_server
%attr(0750,%{_srvuser},%{_srvuser}) %dir %{_var}/log/%{name}-servers
%attr(0750,root,%{_srvuser}) %dir %{_sysconfdir}/%{name}_server.conf.d
%if %{_has_systemd}
%{_unitdir}/%{name}-server.service
%else
%attr(0755,root,root) %{_initrddir}/%{name}-server
%endif
%attr(0755,root,root) %{_sbindir}/%{name}_server
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/mysql
%dir %{_datadir}/%{name}/mysql/option-patches
%{_datadir}/%{name}/mysql/*.sql.gz
%{_datadir}/%{name}/mysql/option-patches/*.sql.gz
%{_datadir}/%{name}/mysql/utf8mb4_convert.sql
%attr(0750,root,%{_srvuser}) %{_datadir}/%{name}/mysql/dbsetup.sh
%attr(0750,root,%{_srvuser}) %{_datadir}/%{name}/mysql/db_primary_keys.sh
%attr(0755,%{_srvuser},%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}
%attr(0755,%{_srvuser},%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/tmp
%attr(0755,%{_srvuser},%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/socket
%attr(0755,root,%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/alertscripts
%attr(0755,root,%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/externalscripts
%attr(0755,root,%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/ssl
%attr(0755,root,%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/ssl/certs
%attr(0755,root,%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/ssl/keys
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/modules
%{_mandir}/man8/%{name}_server.8*

%files proxy
%defattr(-,root,root,-)
%doc misc/snmptrap/zabbix_trap_receiver.pl
%attr(0640,root,%{_srvuser}) %config(noreplace) %{_sysconfdir}/%{name}_proxy.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}_proxy
%attr(0750,%{_srvuser},%{_srvuser}) %dir %{_var}/log/%{name}-servers
%attr(0750,root,%{_srvuser}) %dir %{_sysconfdir}/%{name}_proxy.conf.d
%if %{_has_systemd}
%{_unitdir}/%{name}-proxy.service
%else
%attr(0755,root,root) %{_initrddir}/%{name}-proxy
%endif
%attr(0755,root,root) %{_sbindir}/%{name}_proxy
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/mysql
%dir %{_datadir}/%{name}/mysql/option-patches
%{_datadir}/%{name}/mysql/schema.sql.gz
%{_datadir}/%{name}/mysql/option-patches/history_pk_prepare.sql.gz
%{_datadir}/%{name}/mysql/utf8mb4_convert.sql
%attr(0750,root,%{_srvuser}) %{_datadir}/%{name}/mysql/dbsetup_proxy.sh
%attr(0750,root,%{_srvuser}) %{_datadir}/%{name}/mysql/db_primary_keys_proxy.sh
%attr(0755,%{_srvuser},%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}
%attr(0755,%{_srvuser},%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/tmp
%attr(0755,%{_srvuser},%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/socket
%attr(0755,root,%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/externalscripts
%attr(0755,root,%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/ssl
%attr(0755,root,%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/ssl/certs
%attr(0755,root,%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}/ssl/keys
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/modules
%{_mandir}/man8/%{name}_proxy.8*

%files java
%defattr(-,root,root,-)
%attr(0640,root,%{_srvuser}) %config(noreplace) %{_sysconfdir}/%{name}_java.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}-java
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}_java
%attr(0750,%{_srvuser},%{_srvuser}) %dir %{_var}/log/%{name}-servers
%if %{_has_systemd}
%{_unitdir}/%{name}-java.service
%else
%attr(0755,root,root) %{_initrddir}/%{name}-java
%endif
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/java
%dir %{_datadir}/%{name}/java/bin
%{_datadir}/%{name}/java/bin/*.jar
%attr(0755,root,root) %{_datadir}/%{name}/java/bin/%{name}_java.sh
%{_datadir}/%{name}/java/lib
%attr(0755,%{_srvuser},%{_srvuser}) %dir %{_localstatedir}/lib/%{_srvuser}

%if %{_with_webui}
%files webui
%defattr(-,root,root,-)
%attr(0640,root,apache) %config(noreplace) %{_sysconfdir}/%{name}_webui*.conf
%dir %{_datadir}/%{name}
%{_webappsdir}
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/php-fpm.d/%{name}.conf
%endif
%endif

%changelog
* Wed Feb 26 2025 Simon Matter <simon.matter@invoca.ch> 6.0.39-2
- upgrade slf4j to 2.0.17

* Tue Feb 25 2025 Simon Matter <simon.matter@invoca.ch> 6.0.39-1
- upgrade to 6.0.39

* Tue Jan 28 2025 Simon Matter <simon.matter@invoca.ch> 6.0.38-1
- upgrade to 6.0.38

* Mon Jan 13 2025 Simon Matter <simon.matter@invoca.ch> 6.0.37-1
- upgrade to 6.0.37

* Fri Oct 04 2024 Simon Matter <simon.matter@invoca.ch> 6.0.34-1
- upgrade to 6.0.34

* Thu Aug 29 2024 Simon Matter <simon.matter@invoca.ch> 6.0.33-2
- upgrade slf4j to 2.0.16

* Wed Aug 14 2024 Simon Matter <simon.matter@invoca.ch> 6.0.33-1
- upgrade to 6.0.33

* Tue Aug 13 2024 Simon Matter <simon.matter@invoca.ch> 6.0.33-0.0.rc1.1
- upgrade to 6.0.33rc1

* Tue Jul 16 2024 Simon Matter <simon.matter@invoca.ch> 6.0.32-1
- upgrade to 6.0.32

* Thu Jul 11 2024 Simon Matter <simon.matter@invoca.ch> 6.0.32-0.rc1.1
- upgrade to 6.0.32rc1

* Tue Jun 18 2024 Simon Matter <simon.matter@invoca.ch> 6.0.31-1
- upgrade to 6.0.31

* Thu Jun 13 2024 Simon Matter <simon.matter@invoca.ch> 6.0.31-0.rc1.1
- upgrade to 6.0.31rc1

* Wed May 22 2024 Simon Matter <simon.matter@invoca.ch> 6.0.30-1
- upgrade to 6.0.30

* Sat May 18 2024 Simon Matter <simon.matter@invoca.ch> 6.0.30-0.rc1.2
- start systemd units only after network-online target is reached

* Thu May 16 2024 Simon Matter <simon.matter@invoca.ch> 6.0.30-0.rc1.1
- upgrade to 6.0.30rc1

* Mon Apr 22 2024 Simon Matter <simon.matter@invoca.ch> 6.0.29-1
- upgrade to 6.0.29

* Wed Apr 17 2024 Simon Matter <simon.matter@invoca.ch> 6.0.29-0.rc1.2
- upgrade slf4j to 2.0.13

* Tue Apr 16 2024 Simon Matter <simon.matter@invoca.ch> 6.0.29-0.rc1.1
- upgrade to 6.0.29rc1

* Mon Mar 25 2024 Simon Matter <simon.matter@invoca.ch> 6.0.28-1
- upgrade to 6.0.28

* Tue Mar 19 2024 Simon Matter <simon.matter@invoca.ch> 6.0.28-0.rc1.1
- upgrade to 6.0.28rc1

* Mon Feb 26 2024 Simon Matter <simon.matter@invoca.ch> 6.0.27-1
- upgrade to 6.0.27
- upgrade logback to 1.3.14
- upgrade slf4j to 2.0.12

* Wed Feb 07 2024 Simon Matter <simon.matter@invoca.ch> 6.0.26-2
- upgrade logback to 1.2.13

* Mon Jan 29 2024 Simon Matter <simon.matter@invoca.ch> 6.0.26-1
- upgrade to 6.0.26

* Wed Dec 13 2023 Simon Matter <simon.matter@invoca.ch> 6.0.25-1
- upgrade to 6.0.25

* Thu Nov 30 2023 Simon Matter <simon.matter@invoca.ch> 6.0.24-1
- upgrade to 6.0.24

* Fri Nov 24 2023 Simon Matter <simon.matter@invoca.ch> 6.0.24-0.rc1.1
- upgrade to 6.0.24rc1

* Wed Nov 15 2023 Simon Matter <simon.matter@invoca.ch> 6.0.23-2
- replace script to upgrade database to primary keys
- fix uname wrapper

* Sat Nov 11 2023 Simon Matter <simon.matter@invoca.ch> 6.0.23-1
- change summaries

* Thu Nov 09 2023 Simon Matter <simon.matter@invoca.ch> 6.0.23-0.9
- only start services after hostname resolution is up

* Wed Nov 08 2023 Simon Matter <simon.matter@invoca.ch> 6.0.23-0.8
- do not hide STDERR of agent when started from init script

* Tue Oct 31 2023 Simon Matter <simon.matter@invoca.ch> 6.0.23-0.1
- upgrade to 6.0.23

* Tue Oct 24 2023 Simon Matter <simon.matter@invoca.ch> 6.0.23-0.rc1.0.1
- upgrade to 6.0.23rc1

* Tue Sep 26 2023 Simon Matter <simon.matter@invoca.ch> 6.0.22-0.1
- upgrade to 6.0.22

* Tue Sep 19 2023 Simon Matter <simon.matter@invoca.ch> 6.0.22-0.rc1.0.1
- upgrade to 6.0.22rc1

* Wed Aug 23 2023 Simon Matter <simon.matter@invoca.ch> 6.0.21-0.1
- upgrade to 6.0.21

* Wed Aug 16 2023 Simon Matter <simon.matter@invoca.ch> 6.0.21-0.rc1.0.1
- upgrade to 6.0.21rc1

* Mon Aug 14 2023 Simon Matter <simon.matter@invoca.ch> 6.0.20-0.1
- upgrade to 6.0.20

* Mon Jul 24 2023 Simon Matter <simon.matter@invoca.ch> 6.0.20-0.rc1.0.1
- upgrade to 6.0.20rc1

* Wed Jun 28 2023 Simon Matter <simon.matter@invoca.ch> 6.0.19-0.1
- upgrade to 6.0.19

* Tue Jun 20 2023 Simon Matter <simon.matter@invoca.ch> 6.0.19-0.rc1.0.1
- upgrade to 6.0.19rc1

* Tue May 30 2023 Simon Matter <simon.matter@invoca.ch> 6.0.18-0.1
- upgrade to 6.0.18

* Tue Apr 25 2023 Simon Matter <simon.matter@invoca.ch> 6.0.17-0.1
- upgrade to 6.0.17

* Thu Apr 13 2023 Simon Matter <simon.matter@invoca.ch> 6.0.16-0.1
- upgrade to 6.0.16

* Tue Apr 04 2023 Simon Matter <simon.matter@invoca.ch> 6.0.15-0.1
- upgrade logback to 1.2.12

* Sat Apr 01 2023 Simon Matter <simon.matter@invoca.ch> 6.0.15-0.1
- upgrade to 6.0.15

* Fri Mar 10 2023 Simon Matter <simon.matter@invoca.ch> 6.0.14-0.1
- upgrade to 6.0.14

* Thu Feb 02 2023 Simon Matter <simon.matter@invoca.ch> 6.0.13-0.1
- upgrade to 6.0.13

* Tue Apr 05 2022 Simon Matter <simon.matter@invoca.ch> 5.4.12-0.1
- upgrade to 5.4.12

* Wed Mar 09 2022 Simon Matter <simon.matter@invoca.ch> 5.4.11-0.1
- upgrade logback to 1.2.11

* Wed Mar 02 2022 Simon Matter <simon.matter@invoca.ch> 5.4.11-0.1
- upgrade to 5.4.11
- upgrade slf4j to 1.7.36

* Mon Jan 31 2022 Simon Matter <simon.matter@invoca.ch> 5.4.10-0.1
- upgrade to 5.4.10
- upgrade slf4j to 1.7.35

* Fri Dec 24 2021 Simon Matter <simon.matter@invoca.ch> 5.4.9-0.1
- upgrade logback to 1.2.10

* Thu Dec 23 2021 Simon Matter <simon.matter@invoca.ch> 5.4.9-0.1
- upgrade to 5.4.9

* Tue Nov 30 2021 Simon Matter <simon.matter@invoca.ch> 5.4.8-0.1
- upgrade to 5.4.8

* Fri Oct 29 2021 Simon Matter <simon.matter@invoca.ch> 5.4.7-0.1
- upgrade to 5.4.7

* Tue Oct 19 2021 Simon Matter <simon.matter@invoca.ch> 5.4.6-0.1
- upgrade to 5.4.6

* Thu Sep 30 2021 Simon Matter <simon.matter@invoca.ch> 5.4.5-0.1
- upgrade to 5.4.5

* Tue Aug 31 2021 Simon Matter <simon.matter@invoca.ch> 5.4.4-0.1
- upgrade to 5.4.4

* Thu Jul 22 2021 Simon Matter <simon.matter@invoca.ch> 5.4.3-0.1
- upgrade to 5.4.3

* Tue Jun 29 2021 Simon Matter <simon.matter@invoca.ch> 5.4.2-0.1
- upgrade to 5.4.2

* Tue Jun 08 2021 Simon Matter <simon.matter@invoca.ch> 5.4.1-0.1
- upgrade to 5.4.1

* Tue May 18 2021 Simon Matter <simon.matter@invoca.ch> 5.4.0-0.1
- upgrade to 5.4.0

* Tue Mar 30 2021 Simon Matter <simon.matter@invoca.ch> 5.2.6-0.1
- upgrade to 5.2.6

* Tue Feb 23 2021 Simon Matter <simon.matter@invoca.ch> 5.2.5-0.1
- upgrade to 5.2.5

* Tue Jan 26 2021 Simon Matter <simon.matter@invoca.ch> 5.2.4-0.1
- upgrade to 5.2.4

* Tue Dec 22 2020 Simon Matter <simon.matter@invoca.ch> 5.2.3-0.1
- upgrade to 5.2.3

* Tue Dec 01 2020 Simon Matter <simon.matter@invoca.ch> 5.2.2-0.1
- upgrade to 5.2.2

* Tue Nov 10 2020 Simon Matter <simon.matter@invoca.ch> 5.2.1-0.1
- upgrade to 5.2.1

* Tue Oct 27 2020 Simon Matter <simon.matter@invoca.ch> 5.2.0-0.1
- upgrade to 5.2.0

* Tue Oct 27 2020 Simon Matter <simon.matter@invoca.ch> 5.0.5-0.1
- upgrade to 5.0.5

* Wed Sep 30 2020 Simon Matter <simon.matter@invoca.ch> 5.0.4-0.1
- upgrade to 5.0.4

* Tue Aug 25 2020 Simon Matter <simon.matter@invoca.ch> 5.0.3-0.1
- upgrade to 5.0.3

* Tue Aug 18 2020 Simon Matter <simon.matter@invoca.ch> 5.0.3-0.rc2.0.1
- upgrade to 5.0.3rc2

* Thu Aug 13 2020 Simon Matter <simon.matter@invoca.ch> 5.0.3-0.rc1.0.1
- upgrade to 5.0.3rc1

* Tue Jul 14 2020 Simon Matter <simon.matter@invoca.ch> 5.0.2-1
- upgrade to 5.0.2

* Wed Jul 08 2020 Simon Matter <simon.matter@invoca.ch> 5.0.2-0.rc1.1
- upgrade to 5.0.2rc1

* Mon May 25 2020 Simon Matter <simon.matter@invoca.ch> 5.0.1-1
- upgrade to 5.0.1

* Tue May 19 2020 Simon Matter <simon.matter@invoca.ch> 5.0.1-0.rc1.1
- upgrade to 5.0.1rc1

* Thu May 14 2020 Simon Matter <simon.matter@invoca.ch> 5.0.0-1
- upgrade to 5.0.0

* Mon Apr 27 2020 Simon Matter <simon.matter@invoca.ch> 4.4.8-1
- upgrade to 4.4.8

* Tue Apr 14 2020 Simon Matter <simon.matter@invoca.ch> 4.4.7-3
- cosmetic spec fixes

* Thu Apr 09 2020 Simon Matter <simon.matter@invoca.ch> 4.4.7-2
- add support for EL8

* Tue Mar 24 2020 Simon Matter <simon.matter@invoca.ch> 4.4.7-1
- upgrade to 4.4.7

* Sat Feb 22 2020 Simon Matter <simon.matter@invoca.ch> 4.4.6-1
- upgrade to 4.4.6

* Wed Jan 29 2020 Simon Matter <simon.matter@invoca.ch> 4.4.5-1
- upgrade to 4.4.5

* Fri Dec 20 2019 Simon Matter <simon.matter@invoca.ch> 4.4.4-1
- upgrade to 4.4.4

* Thu Nov 28 2019 Simon Matter <simon.matter@invoca.ch> 4.4.3-1
- upgrade to 4.4.3

* Tue Nov 26 2019 Simon Matter <simon.matter@invoca.ch> 4.4.2-1
- upgrade to 4.4.2

* Fri Nov 08 2019 Simon Matter <simon.matter@invoca.ch> 4.4.1-1
- upgrade to 4.4.1

* Wed Oct 30 2019 Simon Matter <simon.matter@invoca.ch> 4.2.8-1
- upgrade to 4.2.8
- upgrade logback to 1.3.0-alpha4
- upgrade slf4j to 1.8.0-beta4

* Thu Oct 03 2019 Simon Matter <simon.matter@invoca.ch> 4.2.7-1
- upgrade to 4.2.7

* Thu Sep 05 2019 Simon Matter <simon.matter@invoca.ch> 4.2.6-1
- upgrade to 4.2.6

* Tue Jul 30 2019 Simon Matter <simon.matter@invoca.ch> 4.2.5-1
- upgrade to 4.2.5

* Thu Jun 27 2019 Simon Matter <simon.matter@invoca.ch> 4.2.4-1
- upgrade to 4.2.4

* Wed Jun 12 2019 Simon Matter <simon.matter@invoca.ch> 4.2.3-1
- upgrade to 4.2.3

* Sat Jun 01 2019 Simon Matter <simon.matter@invoca.ch> 4.2.2-1
- upgrade to 4.2.2

* Tue Apr 23 2019 Simon Matter <simon.matter@invoca.ch> 4.2.1-1
- upgrade to 4.2.1

* Tue Apr 09 2019 Simon Matter <simon.matter@invoca.ch> 4.2.0-1
- upgrade to 4.2.0

* Fri Mar 29 2019 Simon Matter <simon.matter@invoca.ch> 4.0.6-1
- upgrade to 4.0.6

* Tue Feb 26 2019 Simon Matter <simon.matter@invoca.ch> 4.0.5-1
- upgrade to 4.0.5

* Tue Feb 19 2019 Simon Matter <simon.matter@invoca.ch> 4.0.5-0.1.rc1.1
- upgrade to 4.0.5rc1

* Mon Feb 04 2019 Simon Matter <simon.matter@invoca.ch> 4.0.4-1
- upgrade to 4.0.4

* Fri Feb 01 2019 Simon Matter <simon.matter@invoca.ch> 4.0.4-0.1.rc3.1
- upgrade to 4.0.4rc3

* Thu Jan 31 2019 Simon Matter <simon.matter@invoca.ch> 4.0.4-0.1.rc2.1
- upgrade to 4.0.4rc2

* Thu Jan 03 2019 Simon Matter <simon.matter@invoca.ch> 4.0.3-1
- improve agent init script

* Fri Dec 21 2018 Simon Matter <simon.matter@invoca.ch> 4.0.3-0
- upgrade to 4.0.3

* Wed Nov 28 2018 Simon Matter <simon.matter@invoca.ch> 4.0.2-1
- upgrade to 4.0.2

* Wed Nov 07 2018 Simon Matter <simon.matter@invoca.ch> 4.0.1-1
- upgrade to 4.0.1

* Mon Sep 17 2018 Simon Matter <simon.matter@invoca.ch> 3.4.14-1
- upgrade to 3.4.14

* Wed Aug 29 2018 Simon Matter <simon.matter@invoca.ch> 3.4.13-1
- upgrade to 3.4.13

* Wed Aug 22 2018 Simon Matter <simon.matter@invoca.ch> 3.4.13-0.1.rc1.1
- upgrade to 3.4.13rc1
- add compat_pcre patch

* Tue Jul 31 2018 Simon Matter <simon.matter@invoca.ch> 3.4.12-1
- upgrade to 3.4.12

* Tue Jul 24 2018 Simon Matter <simon.matter@invoca.ch> 3.4.12-0.1.rc1.1
- upgrade to 3.4.12rc1

* Tue Jun 26 2018 Simon Matter <simon.matter@invoca.ch> 3.4.11-1
- upgrade to 3.4.11

* Tue Jun 19 2018 Simon Matter <simon.matter@invoca.ch> 3.4.11-0.1.rc1.1
- upgrade to 3.4.11rc1

* Tue Jun 05 2018 Simon Matter <simon.matter@invoca.ch> 3.4.10-1
- upgrade to 3.4.10

* Mon Jun 04 2018 Simon Matter <simon.matter@invoca.ch> 3.4.10-0.1.rc1.1
- upgrade to 3.4.10rc1

* Thu May 10 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-1
- upgrade to 3.4.9

* Mon May 07 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.0.rc3_80432.1
- upgrade to 3.4.9rc3-80432

* Mon May 07 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.1.rc3.1
- upgrade to 3.4.9rc3

* Thu May 03 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.0.rc3_80371.1
- upgrade to 3.4.9rc3-80371

* Wed May 02 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc2.1
- upgrade to 3.4.9rc2

* Mon Apr 30 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc2_80300.1
- upgrade to 3.4.9rc2-80300

* Tue Apr 24 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc1.1
- upgrade to 3.4.9rc1

* Mon Apr 23 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc1_80076.1
- upgrade to 3.4.9rc1-80076

* Thu Apr 19 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc1_79913.1
- upgrade to 3.4.9rc1-79913

* Wed Apr 18 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc1_79851.1
- upgrade to 3.4.9rc1-79851

* Mon Apr 16 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc1_79733.1
- upgrade to 3.4.9rc1-79733

* Fri Apr 13 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc1_79674.1
- upgrade to 3.4.9rc1-79674

* Thu Apr 12 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc1_79643.1
- upgrade to 3.4.9rc1-79643

* Wed Apr 11 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc1_79555.1
- upgrade to 3.4.9rc1-79555

* Wed Apr 11 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc1_79542.1
- upgrade to 3.4.9rc1-79542

* Tue Apr 10 2018 Simon Matter <simon.matter@invoca.ch> 3.4.9-0.rc1_79487.1
- upgrade to 3.4.9rc1-79487

* Thu Apr 05 2018 Simon Matter <simon.matter@invoca.ch> 3.4.8-1
- upgrade to 3.4.8

* Wed Apr 04 2018 Simon Matter <simon.matter@invoca.ch> 3.4.8-0.rc1.1
- upgrade to 3.4.8rc1

* Sat Feb 17 2018 Simon Matter <simon.matter@invoca.ch> 3.4.7-1
- upgrade to 3.4.7

* Tue Feb 13 2018 Simon Matter <simon.matter@invoca.ch> 3.4.7-0.rc2_77571.1
- upgrade to 3.4.7rc2-77571
- upgrade bundled logback to 1.3.0-alpha4 (including slf4j-api-1.8.0-beta1)

* Wed Feb 07 2018 Simon Matter <simon.matter@invoca.ch> 3.4.7-0.rc2_77410.1
- upgrade to 3.4.7rc2-77410
- upgrade bundled logback to 1.3.0-alpha2 (including slf4j-api-1.8.0-beta1)

* Mon Jan 15 2018 Simon Matter <simon.matter@invoca.ch> 3.4.6-1
- upgrade to 3.4.6

* Wed Jan 10 2018 Simon Matter <simon.matter@invoca.ch> 3.4.6-0.rc1.1
- upgrade to 3.4.6rc1

* Tue Jan 09 2018 Simon Matter <simon.matter@invoca.ch> 3.4.5-3
- fix php config file

* Thu Jan 04 2018 Simon Matter <simon.matter@invoca.ch> 3.4.5-2
- change socket dir to /var/lib/zbxsrv/socket/
- add cleanup of sockets to init/service files

* Wed Jan 03 2018 Simon Matter <simon.matter@invoca.ch> 3.4.5-1
- upgrade to 3.4.5

* Fri Dec 29 2017 Simon Matter <simon.matter@invoca.ch> 3.2.11-1
- upgrade to 3.2.11

* Fri Nov 10 2017 Simon Matter <simon.matter@invoca.ch> 3.2.10-1
- upgrade to 3.2.10

* Wed Oct 18 2017 Simon Matter <simon.matter@invoca.ch> 3.2.9-1
- upgrade to 3.2.9

* Tue Sep 26 2017 Simon Matter <simon.matter@invoca.ch> 3.2.8-1
- upgrade to 3.2.8

* Tue Jul 18 2017 Simon Matter <simon.matter@invoca.ch> 3.2.7-1
- upgrade to 3.2.7

* Tue Jul 11 2017 Simon Matter <simon.matter@invoca.ch> 3.2.7-0.rc1.1
- upgrade to 3.2.7rc1
- upgrade private m4 to 1.4.18

* Sat May 06 2017 Simon Matter <simon.matter@invoca.ch> 3.2.6-1
- upgrade to 3.2.6

* Mon Apr 24 2017 Simon Matter <simon.matter@invoca.ch> 3.2.5-2
- add patch for fping 4

* Fri Apr 21 2017 Simon Matter <simon.matter@invoca.ch> 3.2.5-1
- upgrade to 3.2.5

* Sat Apr 01 2017 Simon Matter <simon.matter@invoca.ch> 3.2.4-1.2
- upgrade bundled logback to 1.2.3 (including slf4j-api-1.7.25)

* Mon Mar 20 2017 Simon Matter <simon.matter@invoca.ch> 3.2.4-1.1
- upgrade bundled logback to 1.2.2 (including slf4j-api-1.7.25)

* Mon Feb 27 2017 Simon Matter <simon.matter@invoca.ch> 3.2.4-1
- upgrade to 3.2.4

* Wed Feb 22 2017 Simon Matter <simon.matter@invoca.ch> 3.2.4-0.rc1.1
- upgrade to 3.2.4rc1

* Fri Feb 10 2017 Simon Matter <simon.matter@invoca.ch> 3.2.3-5
- upgrade bundled logback to 1.2.1 (including slf4j-api-1.7.22)

* Mon Feb 06 2017 Simon Matter <simon.matter@invoca.ch> 3.2.3-3
- upgrade bundled logback to 1.1.10 (including slf4j-api-1.7.22)

* Mon Jan 23 2017 Simon Matter <simon.matter@invoca.ch> 3.2.3-2
- upgrade bundled logback to 1.1.9 (including slf4j-api-1.7.22)

* Tue Dec 27 2016 Simon Matter <simon.matter@invoca.ch> 3.2.3-1
- upgrade to 3.2.3

* Mon Dec 12 2016 Simon Matter <simon.matter@invoca.ch> 3.2.2-2
- upgrade bundled logback to 1.1.8 (including slf4j-api-1.7.21)

* Wed Dec 07 2016 Simon Matter <simon.matter@invoca.ch> 3.2.2-1
- upgrade to 3.2.2

* Tue Dec 06 2016 Simon Matter <simon.matter@invoca.ch> 3.2.2-0.rc1.1
- upgrade to 3.2.2rc1

* Fri Sep 30 2016 Simon Matter <simon.matter@invoca.ch> 3.2.1-1
- upgrade to 3.2.1

* Wed Sep 28 2016 Simon Matter <simon.matter@invoca.ch> 3.2.1-0.rc1.1
- upgrade to 3.2.1rc1

* Wed Sep 14 2016 Simon Matter <simon.matter@invoca.ch> 3.2.0-1
- upgrade to 3.2.0

* Tue Sep 13 2016 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.rc2.1
- upgrade to 3.2.0rc2

* Sat Jul 23 2016 Simon Matter <simon.matter@invoca.ch> 3.0.4-1
- upgrade to 3.0.4

* Thu May 19 2016 Simon Matter <simon.matter@invoca.ch> 3.0.3-1
- upgrade to 3.0.3

* Wed Apr 20 2016 Simon Matter <simon.matter@invoca.ch> 3.0.2-1
- upgrade to 3.0.2
- remove old_libxml2 patch

* Thu Apr 14 2016 Simon Matter <simon.matter@invoca.ch> 3.0.2-0.rc1.1
- upgrade to 3.0.2rc1
- remove fping3 patch
- upgrade bundled logback to 1.1.7 (including slf4j-api-1.7.20)

* Tue Mar 08 2016 Simon Matter <simon.matter@invoca.ch> 3.0.1-2
- fix apache config for EL5

* Mon Mar 07 2016 Simon Matter <simon.matter@invoca.ch> 3.0.1-1
- upgrade to 3.0.1
- upgrade bundled logback to 1.1.6 (including slf4j-api-1.7.18)

* Mon Feb 15 2016 Simon Matter <simon.matter@invoca.ch> 2.4.7-3
- upgrade bundled logback to 1.1.5

* Fri Feb 12 2016 Simon Matter <simon.matter@invoca.ch> 2.4.7-2
- upgrade bundled logback to 1.1.4 (including slf4j-api-1.7.16)

* Fri Nov 13 2015 Simon Matter <simon.matter@invoca.ch> 2.4.7-1
- upgrade to 2.4.7

* Mon Sep 14 2015 Simon Matter <simon.matter@invoca.ch> 2.4.6-2
- move server logs to zabbix-servers directory

* Tue Aug 11 2015 Simon Matter <simon.matter@invoca.ch> 2.4.6-1
- upgrade to 2.4.6

* Fri Jul 03 2015 Simon Matter <simon.matter@invoca.ch> 2.4.5-4
- upgrade private autotools to autoconf-2.69/m4-1.4.17

* Wed May 13 2015 Simon Matter <simon.matter@invoca.ch> 2.4.5-3
- small spec fixes for systemd

* Tue May 05 2015 Simon Matter <simon.matter@invoca.ch> 2.4.5-2
- cosmetic changes

* Wed Apr 22 2015 Simon Matter <simon.matter@invoca.ch> 2.4.5-1
- upgrade to 2.4.5

* Thu Mar 26 2015 Simon Matter <simon.matter@invoca.ch> 2.4.4-2
- upgrade bundled logback to 1.1.3 (including slf4j-api-1.7.7)

* Mon Feb 23 2015 Simon Matter <simon.matter@invoca.ch> 2.4.4-1
- upgrade to 2.4.4

* Fri Jan 16 2015 Simon Matter <simon.matter@invoca.ch> 2.4.3-3
- add minor fix to systemd support

* Thu Jan 15 2015 Simon Matter <simon.matter@invoca.ch> 2.4.3-2
- add support for systemd

* Thu Dec 18 2014 Simon Matter <simon.matter@invoca.ch> 2.4.3-1
- upgrade to 2.4.3

* Wed Nov 05 2014 Simon Matter <simon.matter@invoca.ch> 2.4.2-1
- upgrade to 2.4.2

* Fri Oct 10 2014 Simon Matter <simon.matter@invoca.ch> 2.4.1-1
- upgrade to 2.4.1

* Wed Sep 17 2014 Simon Matter <simon.matter@invoca.ch> 2.4.0-1
- upgrade to 2.4.0

* Thu Aug 28 2014 Simon Matter <simon.matter@invoca.ch> 2.2.6-1
- upgrade to 2.2.6

* Fri Jul 18 2014 Simon Matter <simon.matter@invoca.ch> 2.2.5-1
- upgrade to 2.2.5

* Tue Jun 24 2014 Simon Matter <simon.matter@invoca.ch> 2.2.4-1
- upgrade to 2.2.4

* Tue Apr 08 2014 Simon Matter <simon.matter@invoca.ch> 2.2.3-1
- upgrade to 2.2.3

* Thu Apr 03 2014 Simon Matter <simon.matter@invoca.ch> 2.2.2-3
- add libxml2 to server builds to enable VMware monitoring

* Thu Apr 03 2014 Simon Matter <simon.matter@invoca.ch> 2.2.2-2
- upgrade bundled logback to 1.1.2 (including slf4j-api-1.7.6)

* Wed Feb 12 2014 Simon Matter <simon.matter@invoca.ch> 2.2.2-1
- upgrade to 2.2.2

* Thu Feb 06 2014 Simon Matter <simon.matter@invoca.ch> 2.2.1-4
- upgrade bundled logback to 1.1.1 (including slf4j-api-1.7.6)

* Wed Jan 29 2014 Simon Matter <simon.matter@invoca.ch> 2.2.1-3
- upgrade bundled logback to 1.1.0 (including slf4j-api-1.7.5)

* Sat Dec 28 2013 Simon Matter <simon.matter@invoca.ch> 2.2.1-2
- disable setup in menu

* Mon Dec 23 2013 Simon Matter <simon.matter@invoca.ch> 2.2.1-1
- upgrade to 2.2.1

* Tue Nov 12 2013 Simon Matter <simon.matter@invoca.ch> 2.2.0-1
- upgrade to 2.2.0

* Tue Oct 22 2013 Simon Matter <simon.matter@invoca.ch> 2.0.9-2
- update patch for ZBX-4986

* Wed Oct 09 2013 Simon Matter <simon.matter@invoca.ch> 2.0.9-1
- upgrade to 2.0.9

* Thu Aug 22 2013 Simon Matter <simon.matter@invoca.ch> 2.0.8-1
- upgrade to 2.0.8

* Fri Aug 02 2013 Simon Matter <simon.matter@invoca.ch> 2.0.7-1
- upgrade to 2.0.7

* Thu Jun 27 2013 Simon Matter <simon.matter@invoca.ch> 2.0.6-7
- update ZBX-4986 patch

* Mon Jun 24 2013 Simon Matter <simon.matter@invoca.ch> 2.0.6-6
- add patch to set JavaGateway=localhost by default

* Fri Jun 21 2013 Simon Matter <simon.matter@invoca.ch> 2.0.6-5
- add patch for ZBX-4986
- update frontend-php_config patch

* Thu Jun 20 2013 Simon Matter <simon.matter@invoca.ch> 2.0.6-4
- remove comment line from zabbix_java.conf

* Fri May 24 2013 Simon Matter <simon.matter@invoca.ch> 2.0.6-3
- upgrade bundled logback to 1.0.13 (including slf4j-api-1.7.5)
- add patch for ZBX-6526

* Sat May 04 2013 Simon Matter <simon.matter@invoca.ch> 2.0.6-2
- upgrade bundled logback to 1.0.12 (including slf4j-api-1.7.4)

* Tue Apr 23 2013 Simon Matter <simon.matter@invoca.ch> 2.0.6-1
- upgrade to 2.0.6

* Thu Apr 11 2013 Simon Matter <simon.matter@invoca.ch> 2.0.5-2
- upgrade bundled logback to 1.0.11 (including slf4j-api-1.7.4)

* Wed Feb 13 2013 Simon Matter <simon.matter@invoca.ch> 2.0.5-1
- upgrade to 2.0.5

* Wed Feb 06 2013 Simon Matter <simon.matter@invoca.ch> 2.0.5-0.rc1.1
- upgrade to 2.0.5rc1

* Thu Dec 27 2012 Simon Matter <simon.matter@invoca.ch> 2.0.4-1
- upgrade to 2.0.4

* Fri Aug 31 2012 Simon Matter <simon.matter@invoca.ch> 1.8.15-1
- upgrade to 1.8.15

* Sat Jun 30 2012 Simon Matter <simon.matter@invoca.ch> 1.8.14-1
- upgrade to 1.8.14

* Fri May 11 2012 Simon Matter <simon.matter@invoca.ch> 1.8.13-1
- upgrade to 1.8.13

* Wed Apr 25 2012 Simon Matter <simon.matter@invoca.ch> 1.8.12-1
- upgrade to 1.8.12

* Tue Mar 20 2012 Simon Matter <simon.matter@invoca.ch> 1.8.11-1
- upgrade to 1.8.11

* Fri Dec 30 2011 Simon Matter <simon.matter@invoca.ch> 1.8.10-1
- upgrade to 1.8.10

* Wed Nov 23 2011 Simon Matter <simon.matter@invoca.ch> 1.8.9-1
- upgrade to 1.8.9

* Fri Sep 30 2011 Simon Matter <simon.matter@invoca.ch> 1.8.8-1
- upgrade to 1.8.8

* Fri Sep 02 2011 Simon Matter <simon.matter@invoca.ch> 1.8.7-1
- upgrade to 1.8.7

* Wed Aug 10 2011 Simon Matter <simon.matter@invoca.ch> 1.8.6-3
- add more fixes for compatibility with EL6

* Wed Aug 10 2011 Simon Matter <simon.matter@invoca.ch> 1.8.6-2
- change ownership of logdir for compatibility with EL6

* Thu Aug 04 2011 Simon Matter <simon.matter@invoca.ch> 1.8.6-1
- upgrade to 1.8.6

* Wed Aug 03 2011 Simon Matter <simon.matter@invoca.ch> 1.8.5-3
- build with curl support

* Fri Jul 29 2011 Simon Matter <simon.matter@invoca.ch> 1.8.5-2
- add fixes for EL6

* Sat Apr 16 2011 Simon Matter <simon.matter@invoca.ch> 1.8.5-1
- upgrade to 1.8.5

* Fri Apr 15 2011 Simon Matter <simon.matter@invoca.ch> 1.8.5-0.18873.2
- mass rebuild

* Tue Apr 05 2011 Simon Matter <simon.matter@invoca.ch> 1.8.5-0.18873.1
- upgrade to current snapshot

* Wed Jan 05 2011 Simon Matter <simon.matter@invoca.ch> 1.8.4-1
- upgrade to 1.8.4

* Fri Dec 31 2010 Simon Matter <simon.matter@invoca.ch> 1.8.4-0.16556.1
- upgrade to current snapshot
- remove diskstats patches and hope it works now

* Wed Nov 17 2010 Simon Matter <simon.matter@invoca.ch> 1.8.4-0.15548.1
- upgrade to current snapshot
- fix more diskstats issues

* Tue Nov 16 2010 Simon Matter <simon.matter@invoca.ch> 1.8.4-0.15522.1
- upgrade to current snapshot
- fix more diskstats issues

* Tue Nov 16 2010 Simon Matter <simon.matter@invoca.ch> 1.8.4-0.15506.1
- upgrade to current snapshot
- reduce CPU cycles used for diskstats

* Wed Nov 03 2010 Simon Matter <simon.matter@invoca.ch> 1.8.4-0.15432.1
- upgrade to current snapshot
- make diskstats work on cciss devices

* Wed Nov 03 2010 Simon Matter <simon.matter@invoca.ch> 1.8.4-0.15234.1
- upgrade to current snapshot
- add patch to fix template for used disk space on /var

* Tue Nov 02 2010 Simon Matter <simon.matter@invoca.ch> 1.8.4-0.15201.1
- upgrade to current snapshot

* Thu Oct 21 2010 Simon Matter <simon.matter@invoca.ch> 1.8.4-0.14968.1
- upgrade to current snapshot

* Tue Oct 19 2010 Simon Matter <simon.matter@invoca.ch> 1.8.4-0.14932.1
- upgrade to current snapshot
- add patch to disable content-lenght header in jsLoader.php

* Fri Oct 15 2010 Simon Matter <simon.matter@invoca.ch> 1.8.4-0.14887.1
- upgrade to current snapshot

* Wed Oct 06 2010 Simon Matter <simon.matter@invoca.ch> 1.8.4-0.14735.1
- upgrade to current snapshot

* Mon Aug 16 2010 Simon Matter <simon.matter@invoca.ch> 1.8.3-1
- upgrade to 1.8.3

* Wed Aug 11 2010 Simon Matter <simon.matter@invoca.ch> 1.8.3-0.13915.1
- upgrade to current snapshot

* Tue Aug 03 2010 Simon Matter <simon.matter@invoca.ch> 1.8.3-0.13783.1
- upgrade to current snapshot

* Fri Jul 30 2010 Simon Matter <simon.matter@invoca.ch> 1.8.3-0.13697.1
- upgrade to current snapshot

* Tue Jun 29 2010 Simon Matter <simon.matter@invoca.ch> 1.8.3-0.13100.1
- upgrade to current snapshot

* Thu Jun 24 2010 Simon Matter <simon.matter@invoca.ch> 1.8.3-0.13060.1
- upgrade to current snapshot

* Tue Jun 22 2010 Simon Matter <simon.matter@invoca.ch> 1.8.3-0.13028.1
- upgrade to current snapshot

* Sat Jun 19 2010 Simon Matter <simon.matter@invoca.ch> 1.8.3-0.12923.1
- upgrade to current snapshot

* Fri Jun 18 2010 Simon Matter <simon.matter@invoca.ch> 1.8.3-0.12896.1
- upgrade to current snapshot

* Thu Jun 17 2010 Simon Matter <simon.matter@invoca.ch> 1.8.3-0.12857.1
- upgrade to current snapshot

* Fri Jun 11 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-4
- add log-failed-items patch

* Thu Jun 10 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-3
- update zabbix_sender_exitvalue patch

* Thu Jun 10 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-2
- add zabbix_sender_exitvalue patch

* Tue Mar 30 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-1
- upgrade to 1.8.2

* Tue Mar 23 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-0.10989.2
- remove requirement for dejavu-lgc-fonts

* Tue Mar 23 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-0.10989.1
- upgrade to current snapshot
- add patch to remove invalid trigger 12201 from SQL data

* Mon Mar 22 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-0.10947.1
- upgrade to current snapshot

* Fri Mar 19 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-0.10923.1
- upgrade to current snapshot
- add patch to disable usage of imagerotate() for texts

* Thu Mar 18 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-0.3.10896
- add patch to work around https://support.zabbix.com/browse/ZBX-1741

* Thu Mar 18 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-0.2.10896
- modify PHP options apache2 config

* Thu Mar 18 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-0.1.10896
- upgrade to current snapshot

* Wed Mar 17 2010 Simon Matter <simon.matter@invoca.ch> 1.8.2-0.3.20100317
- upgrade to current snapshot
- use make install
- add manpages

* Thu Jan 28 2010 Simon Matter <simon.matter@invoca.ch> 1.8.1-1
- upgrade to 1.8.1

* Tue Dec 15 2009 Simon Matter <simon.matter@invoca.ch> 1.8-1
- upgrade to 1.8

* Tue Dec 08 2009 Simon Matter <simon.matter@invoca.ch> 1.6.8-1
- upgrade to 1.6.8

* Fri Nov 13 2009 Simon Matter <simon.matter@invoca.ch> 1.6.7-1
- upgrade to 1.6.7

* Sat Sep 19 2009 Simon Matter <simon.matter@invoca.ch> 1.6.6-2
- add trigger_value patch

* Wed Aug 26 2009 Simon Matter <simon.matter@invoca.ch> 1.6.6-1
- upgrade to 1.6.6
- change license tag to GPLv2+

* Wed Jun 17 2009 Simon Matter <simon.matter@invoca.ch> 1.6.5-2
- add traceroute patch

* Tue Jun 16 2009 Simon Matter <simon.matter@invoca.ch> 1.6.5-1
- upgrade to 1.6.5

* Wed Apr 08 2009 Simon Matter <simon.matter@invoca.ch> 1.6.4-2
- add node_group patch

* Fri Apr 03 2009 Simon Matter <simon.matter@invoca.ch> 1.6.4-1
- upgrade to 1.6.4

* Fri Apr 03 2009 Simon Matter <simon.matter@invoca.ch> 1.6.4-0.20090403
- upgrade to current snapshot

* Thu Apr 02 2009 Simon Matter <simon.matter@invoca.ch> 1.6.4-0.20090401
- upgrade to current snapshot

* Fri Mar 27 2009 Simon Matter <simon.matter@invoca.ch> 1.6.3-1
- upgrade to 1.6.3

* Thu Mar 12 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-6.20090312
- upgrade to current snapshot

* Wed Mar 11 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-6.20090311
- upgrade to current snapshot
- add cosmetic email patch

* Mon Mar 02 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-6.20090302
- update 1.6.3-pre patch

* Wed Feb 25 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-6.20090225
- update 1.6.3-pre patch

* Fri Feb 20 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-6.20090220
- update 1.6.3-pre patch

* Wed Feb 18 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-6.20090218
- update 1.6.3-pre patch

* Sat Feb 14 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-6.20090214
- update 1.6.3-pre patch

* Fri Feb 13 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-6.20090213
- update 1.6.3-pre patch

* Thu Feb 12 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-6
- update 1.6.3-pre patch
- remove obsolete defines patch
- remove obsolete actions patch

* Wed Feb 11 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-5
- update 1.6.3-pre patch
- add defines patch
- add actions patch

* Tue Feb 10 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-4
- update 1.6.3-pre patch

* Wed Jan 28 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-3
- update 1.6.3-pre patch

* Tue Jan 27 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-2
- include 1.6.3-pre as patch

* Fri Jan 16 2009 Simon Matter <simon.matter@invoca.ch> 1.6.2-1
- upgrade to 1.6.2

* Wed Jan 14 2009 Simon Matter <simon.matter@invoca.ch> 1.6.1-12
- add current snapshot as patch

* Fri Jan 09 2009 Simon Matter <simon.matter@invoca.ch> 1.6.1-11
- modify init script to cleanup fping inputfiles in /tmp
- enhance PHP config file for version 1.6.1

* Wed Jan 07 2009 Simon Matter <simon.matter@invoca.ch> 1.6.1-9
- add jabber support
- more init scripts improvements

* Tue Jan 06 2009 Simon Matter <simon.matter@invoca.ch> 1.6.1-8
- improve init scripts

* Wed Dec 31 2008 Simon Matter <simon.matter@invoca.ch> 1.6.1-7
- add chroot_uname to build environment to detect kernel versions
- remove spool dir and ghost files

* Tue Dec 30 2008 Simon Matter <simon.matter@invoca.ch> 1.6.1-5
- disable ipv6 for now, it doesn't handle dns names for auth correctly

* Mon Dec 29 2008 Simon Matter <simon.matter@invoca.ch> 1.6.1-4
- add /usr/lib/zabbix to server package
- disable active checks in default agent config

* Wed Dec 24 2008 Simon Matter <simon.matter@invoca.ch> 1.6.1-3
- improve init scripts
- improve editing of /etc/services file

* Tue Dec 23 2008 Simon Matter <simon.matter@invoca.ch> 1.6.1-2
- include 1.6.2-pre as patch

* Wed Nov 05 2008 Simon Matter <simon.matter@invoca.ch> 1.6.1-1
- upgrade to 1.6.1

* Fri Sep 19 2008 Simon Matter <simon.matter@invoca.ch> 1.6-1
- upgrade to 1.6

* Thu Jul 24 2008 Simon Matter <simon.matter@invoca.ch> 1.4.6-1
- upgrade to 1.4.6

* Wed Mar 26 2008 Simon Matter <simon.matter@invoca.ch> 1.4.5-1
- upgrade to 1.4.5

* Wed Jan 09 2008 Simon Matter <simon.matter@invoca.ch> 1.4.4-1
- add overview2 patch

* Thu Dec 20 2007 Simon Matter <simon.matter@invoca.ch> 1.4.4-0.2
- add php4_compat patch

* Mon Dec 17 2007 Simon Matter <simon.matter@invoca.ch> 1.4.4-0.1
- upgrade to 1.4.4

* Thu Dec 13 2007 Simon Matter <simon.matter@invoca.ch> 1.4.3-0.1
- upgrade to 1.4.3

* Wed Nov 28 2007 Simon Matter <simon.matter@invoca.ch> 1.4.2-0.7
- add memory patches

* Tue Nov 27 2007 Simon Matter <simon.matter@invoca.ch> 1.4.2-0.6
- add permissions patch

* Fri Nov 23 2007 Simon Matter <simon.matter@invoca.ch> 1.4.2-0.5
- update php config

* Thu Nov 22 2007 Simon Matter <simon.matter@invoca.ch> 1.4.2-0.4
- zabbix-server requires net-snmp

* Wed Oct 31 2007 Simon Matter <simon.matter@invoca.ch> 1.4.2-0.3
- fix sql typo

* Tue Aug 21 2007 Simon Matter <simon.matter@invoca.ch> 1.4.2-0.2
- update to 1.4.2
- don't build server if gcc is too old

* Sat Aug 11 2007 Simon Matter <simon.matter@invoca.ch> 1.4.2-0.1
- update to 1.4.2 snapshot

* Mon Jul 02 2007 Simon Matter <simon.matter@invoca.ch> 1.4.1-1
- update to 1.4.1

* Tue Jun 19 2007 Simon Matter <simon.matter@invoca.ch> 1.4-1
- update to 1.4

* Tue Apr 03 2007 Simon Matter <simon.matter@invoca.ch> 1.1.7-0.1
- update to 1.1.7

* Thu Feb 08 2007 Simon Matter <simon.matter@invoca.ch> 1.1.6-0.2
- add pid patch

* Wed Feb 07 2007 Simon Matter <simon.matter@invoca.ch> 1.1.6-0.1
- update to 1.1.6

* Sun Jan 28 2007 Simon Matter <simon.matter@invoca.ch> 1.1.5-0.1
- update to 1.1.5

* Thu Jan 25 2007 Simon Matter <simon.matter@invoca.ch> 1.1.4-0.4
- add create_trigger_button patch
- add trigger_map patch

* Mon Dec 18 2006 Simon Matter <simon.matter@invoca.ch> 1.1.4-0.3
- add sla_calc patch

* Thu Nov 16 2006 Simon Matter <simon.matter@invoca.ch> 1.1.4-0.2
- add patch to change max number of disk devices to 16

* Wed Nov 15 2006 Simon Matter <simon.matter@invoca.ch> 1.1.4-0.1
- update to 1.1.4

* Fri Nov 10 2006 Simon Matter <simon.matter@invoca.ch> 1.1.3-0.3
- add delta_fix patch

* Fri Nov 03 2006 Simon Matter <simon.matter@invoca.ch> 1.1.3-0.2
- add cpu_nince_system patch
- add stime_in_chart patch

* Tue Oct 24 2006 Simon Matter <simon.matter@invoca.ch> 1.1.3-0.1
- update to 1.1.3

* Sat Sep 30 2006 Simon Matter <simon.matter@invoca.ch> 1.1.2-0.3
- add some small patches
- change Prereq to new style

* Wed Sep 20 2006 Simon Matter <simon.matter@invoca.ch> 1.1.2-0.2
- fix apache2 config file name

* Tue Sep 12 2006 Simon Matter <simon.matter@invoca.ch> 1.1.2-0.1
- update to 1.1.2

* Thu Jul 20 2006 Simon Matter <simon.matter@invoca.ch> 1.1.1-0.1
- update to 1.1.1

* Wed Jul 05 2006 Simon Matter <simon.matter@invoca.ch> 1.1-0.25
- fix ghosted files

* Mon Jul 03 2006 Simon Matter <simon.matter@invoca.ch> 1.1-0.24
- add proc_memory patch
- set the shell of the zabbix user to /sbin/nologin if available
- remove the zabbix user on rpm removal

* Fri Jun 09 2006 Simon Matter <simon.matter@invoca.ch> 1.1-0.23
- update to 1.1
- remove win32, novell and docs subpackages

* Thu Apr 13 2006 Simon Matter <simon.matter@invoca.ch> 1.0-11
- update mrtgext
- change package deps from obsoletes to conflicts to make yum happy

* Thu Apr 21 2005 Simon Matter <simon.matter@invoca.ch>
- updated novell subpackage

* Tue Aug 10 2004 Simon Matter <simon.matter@invoca.ch>
- fixed init scripts

* Wed Jul 28 2004 Simon Matter <simon.matter@invoca.ch>
- require a webserver on the buildhost
- included novell subpackage
- fixed start order of services in init scripts

* Mon Jul 26 2004 Simon Matter <simon.matter@invoca.ch>
- added fping to requires for suckerd

* Thu Jul 22 2004 Simon Matter <simon.matter@invoca.ch>
- included win32 subpackage

* Wed Jul 21 2004 Simon Matter <simon.matter@invoca.ch>
- updated gethostbyname patch
- updated init scripts
- fixed pre/postinstall/upgrade scripts
- moved creation scripts to /usr/share...

* Tue Jul 20 2004 Simon Matter <simon.matter@invoca.ch>
- added gethostbyname patch, allows to configure the server as DNS name
- disabled logrotate because Zabbix has it's own way to handle this
- fixed initscripts to restart reliable after a crash

* Fri Jul 16 2004 Simon Matter <simon.matter@invoca.ch>
- rearranged subpackages
- zabbix now uses UID 95, which is also used by radiusd on newer
  RedHat / Fedora releases. Both allow duplicate (non-unique) UID.

* Wed Jul 14 2004 Simon Matter <simon.matter@invoca.ch>
- initial package
